==> simublocks-1.1.6.tar.gz: simublocks-1.1.6/setup.py <==
# MIT License
#
# Copyright (c) 2020 Anderson Vitor Bento
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import setuptools    

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name = 'simublocks',
    version = '1.1.6',
    description = 'Python Simulation Blocks for Dynamic Systems',
    author = 'Anderson Vitor Bento',
    author_email = 'bentoavb@gmail.com',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/bentoavb/simublocks",
    packages=setuptools.find_packages(),
    entry_points = {
        'console_scripts': ['simublocks=main:main'],
    },
    install_requires=[            
        'numpy',
        'scipy',
        'matplotlib',
        'control'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)

==> simublocks-1.1.7.tar.gz: simublocks-1.1.7/setup.py <==
# MIT License
#
# Copyright (c) 2020 Anderson Vitor Bento
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import setuptools    

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name = 'simublocks',
    version = '1.1.7',
    description = 'Python Simulation Blocks for Dynamic Systems',
    author = 'Anderson Vitor Bento',
    author_email = 'bentoavb@gmail.com',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/bentoavb/simublocks",
    packages=setuptools.find_packages(),
    entry_points = {
        'console_scripts': ['simublocks=simublocks.simublocks:main'],
    },
    install_requires=[            
        'numpy',
        'scipy',
        'matplotlib',
        'control'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
